@@ -8,9 +8,12 @@ localH2O = h2o.init(ip = "localhost", port = 54321, startH2O = TRUE)
 australia.hex = h2o.uploadFile(localH2O, system.file("extdata", "australia.csv", package="h2o"), "australia.hex")
 summary(australia.hex)
 
-australia.pca = h2o.prcomp(australia.hex)
-print(australia.pca)
+australia.pca = h2o.prcomp(australia.hex, k = 8)
+print("Eigenvectors of the PCA model...")
+print(australia.pca@model$eigenvectors)
 screeplot(australia.pca)
 
-australia.pca2 = h2o.prcomp(australia.hex, tol = 0.5, standardize = FALSE)
-print(australia.pca2)
+print("Eigenvectors of the PCA model...")
+australia.pca2 = h2o.prcomp(australia.hex, k = 4, transform = "STANDARDIZE")
+print(australia.pca2@model$eigenvectors)
+screeplot(australia.pca2)
